redvox.common API documentation
Description: Top level common members and functions.

# Module `redvox.common`

Top level common members and functions.

Expand source code

    """
    Top level common members and functions.
    """

    import enum

    class ApiVersion(enum.Enum):
        """
        API versions supported by this SDK
        """

        API900: int = 900
        API1000: int = 1_000

## Sub-modules

`redvox.common.api_conversions`

  Provides functionality for converting between API versions.

`redvox.common.api_reader`

  Read Redvox data from a single directory Data files can be either API 900 or API 1000 data formats

`redvox.common.api_reader_old`

  Read Redvox data from a single directory Data files can be either API 900 or API 1000 data formats The ReadResult object converts api900 data into api …

`redvox.common.constants`

  This is an auxiliary file where regularly used constants can be stored and exported.

`redvox.common.cross_stats`

  This module contains functions for computing the cross correlation between data sets of equal or unequal length.

`redvox.common.data_window`

  This module creates specific time-bounded segments of data for users combines the base data files into a single composite object based on the user …

`redvox.common.data_window_configuration`

  This module provide type-safe data window configuration

`redvox.common.date_time_utils`

  This module contains constants and helper functions for converting between different time bases. All time based functions take inputs and output in UTC.

`redvox.common.errors`

  This module contains custom error definitions used within this SDK.

`redvox.common.file_statistics`

  This module provides utility functions for determining statistics of well structured RedVox data.

`redvox.common.gap_and_pad_utils`
`redvox.common.gui`
`redvox.common.io`

  This module provides IO primitives for working with cross-API RedVox data.

`redvox.common.offset_model`
`redvox.common.parallel_utils`

  Module that contains utilities for working with data in parallel.

`redvox.common.sensor_data`

  Defines generic sensor data and data for API-independent analysis all timestamps are integers in microseconds unless otherwise stated

`redvox.common.sensor_reader_utils`

  This module loads sensor data from Redvox packets

`redvox.common.station`

  Defines generic station objects for API-independent analysis all timestamps are integers in microseconds unless otherwise stated Utilizes …

`redvox.common.station_utils`

  Defines generic station metadata for API-independent analysis all timestamps are floats in microseconds unless otherwise stated

`redvox.common.stats_helper`

  Support for computing statistics Requires numpy

`redvox.common.timesync`

  Modules for extracting time synchronization statistics for API 900 and 1000 data. Currently uses API M packets due to versatility of the packet. Also …

`redvox.common.tri_message_stats`

  Modules for extracting time synchronization statistics according to Tri-Message protocol. All functions assume payload for ONE data packet/decoder …

`redvox.common.versioning`

  This module provides functionality for determining the version of RedVox compressed packets.

## Classes

`class ApiVersion (value, names=None, *, module=None, qualname=None, type=None, start=1)`

  API versions supported by this SDK

  Expand source code

      class ApiVersion(enum.Enum):
          """
          API versions supported by this SDK
          """

          API900: int = 900
          API1000: int = 1_000

  ### Ancestors

  - enum.Enum

  ### Class variables

  `var API1000 : int`
  `var API900 : int`